achillesTables: Names of the tables that contain the results of achilles...

View source: R/classCdmReference.R

achillesTablesR Documentation

Names of the tables that contain the results of achilles analyses

Description

Names of the tables that contain the results of achilles analyses

Usage

achillesTables(version = "5.3")

Arguments

version

Version of the OMOP Common Data Model. Supported options are: "5.3", "5.4", or "5.5".

Value

Names of the tables that contain the results from the achilles analyses

Examples


library(omopgenerics)
achillesTables()


omopgenerics documentation built on Sept. 8, 2026, 9:06 a.m.