| assertCharacter | R Documentation |
Assert that an object is a character and satisfies certain conditions.
assertCharacter(
x,
length = NULL,
na = FALSE,
null = FALSE,
empty = TRUE,
unique = FALSE,
named = FALSE,
minNumCharacter = 0,
nm = deparse1(substitute(x), backtick = TRUE),
call = parent.frame(),
msg = NULL
)
x |
Variable to check. |
length |
Required length. If |
na |
Whether it can contain NA values. |
null |
Whether it can be NULL. |
empty |
Whether it can be empty. |
unique |
Whether it has to contain unique elements. |
named |
Whether it has to be named. |
minNumCharacter |
Minimum number of characters that all elements must have. |
nm |
Name to use in error messages. Defaults to the expression supplied
to |
call |
Call argument that will be passed to |
msg |
Custom error message. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.