cdmAssignTableDoc: Helper for consistent documentation of assigning tables to a...

cdmAssignTableDocR Documentation

Helper for consistent documentation of assigning tables to a CDM reference.

Description

Helper for consistent documentation of assigning tables to a CDM reference.

Arguments

name

Name where the new table will be assigned.

value

Table with the same source as the cdm_reference object.


omopgenerics documentation built on June 17, 2026, 5:07 p.m.