Export a summarised_result object to a CSV file.
exportSummarisedResult(
...,
minCellCount = 5,
fileName = "results_{cdm_name}_{date}.csv",
path = getwd(),
logFile = getOption("omopgenerics.logFile"),
logSqlPath = getOption("omopgenerics.log_sql_path"),
logExplainPath = lifecycle::deprecated()
)A set of summarised_result objects.
Minimum count for suppression purposes.
Name of the file that will be created. Use {cdm_name} to refer to the cdmName of the objects and {date} to add the export date.
Path where the CSV file should be created. It is ignored if fileName is a full file name with a path included.
Path to the log file to export.
Path to the folder that contains the sql logs to export.
deprecated.