getCohortName: Get the cohort name of a certain cohort definition id
Description
Get the cohort name of a certain cohort definition id
Usage
getCohortName(cohort, cohortId = NULL)
Arguments
- cohort
A <cohort_table> object.
- cohortId
Cohort definition id of interest. If NULL all cohort ids are
shown.