View source: R/classCdmReference.R
| guessCdmVersion | R Documentation |
Guess the OMOP Common Data Model version from the cdm_source table. If it
cannot be obtained from there, the table and column names in the cdm are
compared with each supported version and the best match is returned. If
there is no unique best match, NA_character_ is returned.
guessCdmVersion(cdm)
cdm |
A cdm reference or a named list of cdm tables. |
A character vector indicating the guessed cdm version, or
NA_character_ if it cannot be guessed.
cdm <- list(
cdm_source = dplyr::tibble(cdm_version = "v5.4.1")
)
guessCdmVersion(cdm)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.