Skip to contents

Import data source descriptions.

Usage

importDataSourceDescription(path, type = NULL, recursive = FALSE)

Arguments

path

Path to a file or a directory containing files.

type

Type of files to import. If NULL, all supported file types are imported. Currently 'json' and 'csv' are supported.

recursive

If TRUE and path is a directory, search for files will recurse into directories.

Value

A data_source_description object.