listSourceTables: List tables that can be accessed through a cdm object.

View source: R/methodListSourceTables.R

listSourceTablesR Documentation

List tables that can be accessed through a cdm object.

Description

List tables that can be accessed through a cdm object.

Usage

listSourceTables(cdm)

Arguments

cdm

A ⁠<cdm_reference>⁠ object.

Value

A character vector with the names of tables.


omopgenerics documentation built on Sept. 8, 2026, 9:06 a.m.