newReadOnlySource: A new read-only source for the cdm

View source: R/classReadOnly.R

newReadOnlySourceR Documentation

A new read-only source for the cdm

Description

This source can be used for cdm_reference objects that should allow reading existing CDM tables, but should not allow creating, computing, inserting, reading from, or dropping source tables.

Usage

newReadOnlySource()

Value

A read-only source in the format of a cdm source.

Examples


library(omopgenerics)
newReadOnlySource()



omopgenerics documentation built on June 17, 2026, 5:07 p.m.