omopTables: Standard tables that a cdm reference can contain in the OMOP...

View source: R/classCdmReference.R

omopTablesR Documentation

Standard tables that a cdm reference can contain in the OMOP Common Data Model.

Description

Standard tables that a cdm reference can contain in the OMOP Common Data Model.

Usage

omopTables(version = "5.3")

Arguments

version

Version of the OMOP Common Data Model. Supported options are: "5.3", "5.4", or "5.5".

Value

Standard tables

Examples

library(omopgenerics)

omopTables()


omopgenerics documentation built on Sept. 8, 2026, 9:06 a.m.