tmpPrefix: Create a temporary prefix for tables that contains a unique...

View source: R/compute.R

tmpPrefixR Documentation

Create a temporary prefix for tables that contains a unique prefix that starts with tmp.

Description

Create a temporary prefix for tables that contains a unique prefix that starts with tmp.

Usage

tmpPrefix()

Value

A temporary prefix.

Examples

library(omopgenerics)
tmpPrefix()

omopgenerics documentation built on Sept. 8, 2026, 9:06 a.m.