| validateNameArgument | R Documentation |
name is not already used in that cdm.Validate name argument. It must be a snake_case character vector. You can add
a cdm object to check that name is not already used in that cdm.
validateNameArgument(
name,
cdm = NULL,
validation = "error",
null = FALSE,
empty = TRUE,
nm = deparse1(substitute(name), backtick = TRUE),
call = parent.frame()
)
name |
Name of a new table to be added to a cdm object. |
cdm |
A |
validation |
How to perform validation: "error", "warning". |
null |
If TRUE, name can be NULL |
empty |
Whether it can be empty. |
nm |
Name to use in error messages. Defaults to the expression supplied
to |
call |
Call argument passed to |
# this is a validate name
name <- "my_new_table"
validateNameArgument(name)
# this is not
name <- "myTableNAME"
validateNameArgument(name, validation = "warning")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.