| validateWindowArgument | R Documentation |
Validate a window argument. It must be a list of two elements (window start and window end), both must be numeric, integerish by default, and window start must be lower or equal than window end.
validateWindowArgument(
window,
snakeCase = TRUE,
integerish = TRUE,
empty = TRUE,
nm = deparse1(substitute(window), backtick = TRUE),
call = parent.frame()
)
window |
time window |
snakeCase |
return default window name in snake case if TRUE |
integerish |
Whether window values must be integerish. |
empty |
Whether it can be empty. |
nm |
Name to use in error messages. Defaults to the expression supplied
to |
call |
Call argument passed to |
time window
validateWindowArgument(list(c(0, 15), c(-Inf, Inf)))
validateWindowArgument(list(c(0, 15), c(-Inf, Inf)), snakeCase = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.