Learn R Programming

omopgenerics (version 1.4.2)

achillesTables: Names of the tables that contain the results of achilles analyses

Description

Names of the tables that contain the results of achilles analyses

Usage

achillesTables(version = "5.3")

Value

Names of the tables that contain the results from the achilles analyses

Arguments

version

Version of the OMOP Common Data Model. Supported options are: "5.3", "5.4", or "5.5".

Examples

Run this code
# \donttest{
library(omopgenerics)
achillesTables()
# }

Run the code above in your browser using DataLab