powered by
Names of the tables that contain the results of achilles analyses
achillesTables(version = "5.3")
Names of the tables that contain the results from the achilles analyses
Version of the OMOP Common Data Model. Supported options are: "5.3", "5.4", or "5.5".
# \donttest{ library(omopgenerics) achillesTables() # }
Run the code above in your browser using DataLab