Assert that an object is a character and satisfies certain conditions.
assertCharacter(
x,
length = NULL,
na = FALSE,
null = FALSE,
empty = TRUE,
unique = FALSE,
named = FALSE,
minNumCharacter = 0,
nm = deparse1(substitute(x), backtick = TRUE),
call = parent.frame(),
msg = NULL
)Variable to check.
Required length. If NULL length is not checked.
Whether it can contain NA values.
Whether it can be NULL.
Whether it can be empty.
Whether it has to contain unique elements.
Whether it has to be named.
Minimum number of characters that all elements must have.
Name to use in error messages. Defaults to the expression supplied
to x.
Call argument that will be passed to cli.
Custom error message.