Learn R Programming

omopgenerics (version 1.4.1)

cdmAssignTableDoc: Helper for consistent documentation of assigning tables to a CDM reference.

Description

Helper for consistent documentation of assigning tables to a CDM reference.

Arguments

name

Name where the new table will be assigned.

value

Table with the same source as the cdm_reference object.