cdmSelect: Restrict the cdm object to a subset of tables.

View source: R/cdmSelect.R

cdmSelectR Documentation

Restrict the cdm object to a subset of tables.

Description

Restrict the cdm object to a subset of tables.

Usage

cdmSelect(cdm, ...)

Arguments

cdm

A ⁠<cdm_reference>⁠ object.

...

Selection of tables to use, it supports tidyselect expressions.

Value

A cdm_reference with only the specified tables.

Examples

cdm <- emptyCdmReference("my cdm")
cdm

cdm |>
  cdmSelect("person")


omopgenerics documentation built on June 17, 2026, 5:07 p.m.