Get the cohort definition id of a certain name
Usage
getCohortId(cohort, cohortName = NULL)
Arguments
- cohort
A <cohort_table> object.
- cohortName
Names of the cohort of interest or a tidyselect expression
referring to cohort names. If NULL all cohort names are shown.
Value
Cohort definition ids