Learn R Programming

omopgenerics (version 1.4.1)

getCohortId: Get the cohort definition id of a certain name

Description

Get the cohort definition id of a certain name

Usage

getCohortId(cohort, cohortName = NULL)

Value

Cohort definition ids

Arguments

cohort

A <cohort_table> object.

cohortName

Names of the cohort of interest or a tidyselect expression referring to cohort names. If NULL all cohort names are shown.