listSourceTables: List tables that can be accessed through a cdm object.

View source: R/methodListSourceTables.R

listSourceTablesR Documentation

List tables that can be accessed through a cdm object.

Description

List tables that can be accessed through a cdm object.

Usage

listSourceTables(cdm)

Arguments

cdm

A ⁠<cdm_reference>⁠ object.

Value

A character vector with the names of tables.


omopgenerics documentation built on June 17, 2026, 5:07 p.m.