Learn R Programming

omopgenerics (version 1.4.1)

listSourceTables: List tables that can be accessed through a cdm object.

Description

List tables that can be accessed through a cdm object.

Usage

listSourceTables(cdm)

Value

A character vector with the names of tables.

Arguments

cdm

A <cdm_reference> object.