View source: R/classReadOnly.R
| newReadOnlySource | R Documentation |
This source can be used for cdm_reference objects that should allow reading
existing CDM tables, but should not allow creating, computing, inserting,
reading from, or dropping source tables.
newReadOnlySource()
A read-only source in the format of a cdm source.
library(omopgenerics)
newReadOnlySource()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.