Learn R Programming

omopgenerics (version 1.4.1)

newReadOnlySource: A new read-only source for the cdm

Description

This source can be used for cdm_reference objects that should allow reading existing CDM tables, but should not allow creating, computing, inserting, reading from, or dropping source tables.

Usage

newReadOnlySource()

Arguments

Value

A read-only source in the format of a cdm source.

Examples

Run this code
# \donttest{
library(omopgenerics)
newReadOnlySource()
# }

Run the code above in your browser using DataLab