Learn R Programming

omopgenerics (version 1.4.2)

omopTables: Standard tables that a cdm reference can contain in the OMOP Common Data Model.

Description

Standard tables that a cdm reference can contain in the OMOP Common Data Model.

Usage

omopTables(version = "5.3")

Value

Standard tables

Arguments

version

Version of the OMOP Common Data Model. Supported options are: "5.3", "5.4", or "5.5".

Examples

Run this code
library(omopgenerics)

omopTables()

Run the code above in your browser using DataLab