Learn R Programming

omopgenerics (version 1.4.1)

pivotEstimates: Set estimates as columns

Description

Pivot the estimates as new columns in result table.

Usage

pivotEstimates(result, pivotEstimatesBy = "estimate_name", nameStyle = NULL)

Value

A tibble.

Arguments

result

A <summarised_result> object.

pivotEstimatesBy

Names from which to pivot the estimate values wider. If NULL the table will not be pivoted.

nameStyle

Name style (glue package specifications) to customise names when pivoting estimates. If NULL standard tidyr::pivot_wider formatting will be used.

Examples

Run this code
{
  library(dplyr)
  library(omopgenerics)

  x <- tibble(
    "result_id" = 1L,
    "cdm_name" = c("cprd", "eunomia"),
    "group_name" = "cohort_name",
    "group_level" = "my_cohort",
    "strata_name" = "sex",
    "strata_level" = "male",
    "variable_name" = "Age group",
    "variable_level" = "10 to 50",
    "estimate_name" = "count",
    "estimate_type" = "numeric",
    "estimate_value" = "5",
    "additional_name" = "overall",
    "additional_level" = "overall"
  ) |>
    newSummarisedResult()

  x |>
    pivotEstimates()
}

Run the code above in your browser using DataLab