| validateConceptSetArgument | R Documentation |
Validate conceptSet argument. It can either be a list, a codelist, a concept set expression or a codelist with details. The output will always be a codelist.
validateConceptSetArgument(
conceptSet,
cdm = NULL,
empty = TRUE,
validation = "error",
nm = deparse1(substitute(conceptSet), backtick = TRUE),
call = parent.frame()
)
conceptSet |
It can be either a named list of concepts or a codelist, codelist_with_details or concept_set_expression object. |
cdm |
A |
empty |
Whether it can be empty. |
validation |
How to perform validation: "error", "warning". |
nm |
Name to use in error messages. Defaults to the expression supplied
to |
call |
Call argument passed to |
A codelist object.
conceptSet <- list(disease_x = c(1L, 2L))
validateConceptSetArgument(conceptSet)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.