| validateStrataArgument | R Documentation |
To validate a strata list. It makes sure that elements are unique and point to columns in table.
validateStrataArgument(
strata,
table,
empty = TRUE,
nm = deparse1(substitute(strata), backtick = TRUE),
call = parent.frame()
)
strata |
A list of characters that point to columns in table. |
table |
A table with columns. |
empty |
Whether it can be empty. |
nm |
Name to use in error messages. Defaults to the expression supplied
to |
call |
Call argument passed to |
The same strata input or an error if the input is incorrect.
strata <- list("age", "sex", c("age", "sex"))
x <- dplyr::tibble(age = 30L, sex = "Female")
validateStrataArgument(strata, x)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.