Learn R Programming

omopgenerics (version 1.4.1)

validateStrataArgument: To validate a strata list. It makes sure that elements are unique and point to columns in table.

Description

To validate a strata list. It makes sure that elements are unique and point to columns in table.

Usage

validateStrataArgument(
  strata,
  table,
  empty = TRUE,
  nm = deparse1(substitute(strata), backtick = TRUE),
  call = parent.frame()
)

Value

The same strata input or an error if the input is incorrect.

Arguments

strata

A list of characters that point to columns in table.

table

A table with columns.

empty

Whether it can be empty.

nm

Name to use in error messages. Defaults to the expression supplied to strata.

call

Call argument passed to cli functions.

Examples

Run this code
strata <- list("age", "sex", c("age", "sex"))
x <- dplyr::tibble(age = 30L, sex = "Female")

validateStrataArgument(strata, x)

Run the code above in your browser using DataLab