powered by
To validate a strata list. It makes sure that elements are unique and point to columns in table.
validateStrataArgument( strata, table, empty = TRUE, nm = deparse1(substitute(strata), backtick = TRUE), call = parent.frame() )
The same strata input or an error if the input is incorrect.
A list of characters that point to columns in table.
A table with columns.
Whether it can be empty.
Name to use in error messages. Defaults to the expression supplied to strata.
strata
Call argument passed to cli functions.
cli
strata <- list("age", "sex", c("age", "sex")) x <- dplyr::tibble(age = 30L, sex = "Female") validateStrataArgument(strata, x)
Run the code above in your browser using DataLab