validateWindowArgument: Validate a window argument. It must be a list of two elements (window start
and window end), both must be numeric, integerish by default, and window
start must be lower or equal than window end.
Description
Validate a window argument. It must be a list of two elements (window start
and window end), both must be numeric, integerish by default, and window
start must be lower or equal than window end.